@@ -51,22 +51,22 @@
 <context>
     <name>ConnectionSelector</name>
     <message>
-        <location filename="../../gui/connectionselector.cpp" line="69"/>
+        <location filename="../../gui/connectionselector.cpp" line="71"/>
         <source>Use global setting</source>
         <translation>Käytä järj. asetusta</translation>
     </message>
     <message>
-        <location filename="../../gui/connectionselector.cpp" line="70"/>
+        <location filename="../../gui/connectionselector.cpp" line="72"/>
         <source>WLAN connection</source>
         <translation>WLAN-yhteys</translation>
     </message>
     <message>
-        <location filename="../../gui/connectionselector.cpp" line="71"/>
+        <location filename="../../gui/connectionselector.cpp" line="73"/>
         <source>GPRS connection</source>
         <translation>GPRS-yhteys</translation>
     </message>
     <message>
-        <location filename="../../gui/connectionselector.cpp" line="72"/>
+        <location filename="../../gui/connectionselector.cpp" line="74"/>
         <source>Any connection</source>
         <translation>Mikä tahansa yhteys</translation>
     </message>
@@ -164,122 +164,150 @@
 <context>
     <name>EniroGuiConfig</name>
     <message>
-        <location filename="../../gui/eniroguiconfig.cpp" line="36"/>
+        <location filename="../../gui/eniroguiconfig.cpp" line="123"/>
         <source>Eniro username</source>
         <translation>Eniro-tunnus</translation>
     </message>
     <message>
-        <location filename="../../gui/eniroguiconfig.cpp" line="39"/>
+        <location filename="../../gui/eniroguiconfig.cpp" line="126"/>
         <source>Eniro password</source>
         <translation>Eniro-salasana</translation>
     </message>
     <message>
-        <location filename="../../gui/eniroguiconfig.cpp" line="45"/>
+        <location filename="../../gui/eniroguiconfig.cpp" line="79"/>
         <source>Eniro site</source>
         <translation>Eniro-sivusto</translation>
     </message>
     <message>
-        <location filename="../../gui/eniroguiconfig.cpp" line="57"/>
+        <location filename="../../gui/eniroguiconfig.cpp" line="90"/>
         <source>Finnish</source>
         <translation>Suomi</translation>
     </message>
     <message>
-        <location filename="../../gui/eniroguiconfig.cpp" line="60"/>
+        <location filename="../../gui/eniroguiconfig.cpp" line="93"/>
         <source>Swedish</source>
         <translation>Ruotsi</translation>
     </message>
     <message>
-        <location filename="../../gui/eniroguiconfig.cpp" line="63"/>
+        <location filename="../../gui/eniroguiconfig.cpp" line="96"/>
         <source>Danish</source>
         <translation>Tanska</translation>
     </message>
 </context>
+<context>
+    <name>LogWindow</name>
+    <message>
+        <location filename="../../gui/logwindow.cpp" line="30"/>
+        <source>Incoming call log</source>
+        <translation>Puheluloki</translation>
+    </message>
+    <message>
+        <location filename="../../gui/logwindow.cpp" line="31"/>
+        <source>Clear log</source>
+        <translation>Tyhjennä loki</translation>
+    </message>
+    <message>
+        <location filename="../../gui/logwindow.cpp" line="64"/>
+        <source>There are currently no logged calls</source>
+        <translation>Ei kirjattuja puheluita</translation>
+    </message>
+    <message>
+        <location filename="../../gui/logwindow.cpp" line="134"/>
+        <source>%1 (no search results)</source>
+        <translation>%1 (ei hakutuloksia)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="48"/>
+        <location filename="../../gui/mainwindow.cpp" line="49"/>
         <source>Jenirok</source>
         <translation>Jenirok</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="54"/>
-        <location filename="../../gui/mainwindow.cpp" line="151"/>
+        <location filename="../../gui/mainwindow.cpp" line="55"/>
+        <location filename="../../gui/mainwindow.cpp" line="171"/>
         <source>Stop daemon</source>
         <translation>Pysäytä</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="60"/>
-        <location filename="../../gui/mainwindow.cpp" line="117"/>
+        <location filename="../../gui/mainwindow.cpp" line="61"/>
+        <location filename="../../gui/mainwindow.cpp" line="137"/>
         <source>Start daemon</source>
         <translation>Käynnistä</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="65"/>
+        <location filename="../../gui/mainwindow.cpp" line="72"/>
         <source>Search</source>
         <translation>Hae</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="82"/>
+        <location filename="../../gui/mainwindow.cpp" line="76"/>
+        <source>Log</source>
+        <translation>Loki</translation>
+    </message>
+    <message>
+        <location filename="../../gui/mainwindow.cpp" line="97"/>
         <source>Settings</source>
         <translation>Asetukset</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="83"/>
+        <location filename="../../gui/mainwindow.cpp" line="98"/>
         <source>About</source>
         <translation>Tietoa</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="115"/>
+        <location filename="../../gui/mainwindow.cpp" line="135"/>
         <source>Daemon was successfully stopped.</source>
         <translation>Palvelu pysäytettiin onnistuneesti.</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="116"/>
+        <location filename="../../gui/mainwindow.cpp" line="136"/>
         <source>Unable to stop daemon.</source>
         <translation>Palvelun pysäyttäminen ei onnistunut.</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="127"/>
+        <location filename="../../gui/mainwindow.cpp" line="147"/>
         <source>Unable to start daemon</source>
         <translation>Palvelun käynnistäminen ei onnistunut</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="129"/>
+        <location filename="../../gui/mainwindow.cpp" line="149"/>
         <source>Daemon cannot be started because it&apos;s not allowed to connect to the Internet. You have to either allow automatic Internet connection in Jenirok settings or in global Maemo settings.</source>
         <translation>Palvelua ei voida käynnistää, koska sillä ei ole oikeutta yhdistää Internetiin. Sinun täytyy sallia automaattinen yhteyden muodostaminen joko Jenirokin asetuksista tai Maemon omista Internet-asetuksista.</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="133"/>
+        <location filename="../../gui/mainwindow.cpp" line="153"/>
         <source>Open settings</source>
         <translation>Avaa asetukset</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="135"/>
+        <location filename="../../gui/mainwindow.cpp" line="155"/>
         <source>Close</source>
         <translation>Sulje</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="149"/>
+        <location filename="../../gui/mainwindow.cpp" line="169"/>
         <source>Daemon was successfully started.</source>
         <translation>Palvelu käynnistettiin onnistuneesti.</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="150"/>
+        <location filename="../../gui/mainwindow.cpp" line="170"/>
         <source>Unable to start daemon.</source>
         <translation>Palvelun käynnistäminen ei onnistunut.</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="157"/>
+        <location filename="../../gui/mainwindow.cpp" line="177"/>
         <source>Error</source>
         <translation>Virhe</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="181"/>
+        <location filename="../../gui/mainwindow.cpp" line="201"/>
         <source>Info</source>
         <translation>Info</translation>
     </message>
     <message>
-        <location filename="../../gui/mainwindow.cpp" line="181"/>
+        <location filename="../../gui/mainwindow.cpp" line="201"/>
         <source>You need to set login details or other options in settings before using this feature.</source>
         <translation>Sinun täytyy asettaa kirjautumistiedot tai muita asetuksia ennen kuin voit käyttää tätä ominaisuutta.</translation>
     </message>
@@ -292,32 +320,32 @@
         <translation>Hakutulokset</translation>
     </message>
     <message>
-        <location filename="../../gui/resultwindow.cpp" line="163"/>
+        <location filename="../../gui/resultwindow.cpp" line="156"/>
         <source>Connection to server failed</source>
         <translation>Palvelimelle yhdistäminen epäonnistui</translation>
     </message>
     <message>
-        <location filename="../../gui/resultwindow.cpp" line="166"/>
+        <location filename="../../gui/resultwindow.cpp" line="159"/>
         <source>Invalid login details</source>
         <translation>Virheellinen tunnus tai salasana</translation>
     </message>
     <message>
-        <location filename="../../gui/resultwindow.cpp" line="169"/>
+        <location filename="../../gui/resultwindow.cpp" line="162"/>
         <source>Request timed out</source>
         <translation>Pyyntö aikakatkaistiin</translation>
     </message>
     <message>
-        <location filename="../../gui/resultwindow.cpp" line="172"/>
+        <location filename="../../gui/resultwindow.cpp" line="165"/>
         <source>Searching failed:</source>
         <translation>Haku epäonnistui:</translation>
     </message>
     <message>
-        <location filename="../../gui/resultwindow.cpp" line="176"/>
+        <location filename="../../gui/resultwindow.cpp" line="169"/>
         <source>Error</source>
         <translation>Virhe</translation>
     </message>
     <message>
-        <location filename="../../gui/resultwindow.cpp" line="181"/>
+        <location filename="../../gui/resultwindow.cpp" line="174"/>
         <source>No results found</source>
         <translation>Ei hakutuloksia</translation>
     </message>
@@ -325,33 +353,33 @@
 <context>
     <name>SearchDialog</name>
     <message>
-        <location filename="../../gui/searchdialog.cpp" line="30"/>
+        <location filename="../../gui/searchdialog.cpp" line="31"/>
         <location filename="../../gui/searchdialog.cpp" line="55"/>
         <source>Search</source>
         <translation>Hae</translation>
     </message>
     <message>
-        <location filename="../../gui/searchdialog.cpp" line="33"/>
+        <location filename="../../gui/searchdialog.cpp" line="34"/>
         <source>Name/number</source>
         <translation>Numero/nimi</translation>
     </message>
     <message>
-        <location filename="../../gui/searchdialog.cpp" line="39"/>
+        <location filename="../../gui/searchdialog.cpp" line="40"/>
         <source>Location</source>
         <translation>Sijainti</translation>
     </message>
     <message>
-        <location filename="../../gui/searchdialog.cpp" line="44"/>
+        <location filename="../../gui/searchdialog.cpp" line="45"/>
         <source>Type</source>
         <translation>Tyyppi</translation>
     </message>
     <message>
-        <location filename="../../gui/searchdialog.cpp" line="45"/>
+        <location filename="../../gui/searchdialog.cpp" line="118"/>
         <source>Persons</source>
         <translation>Henkilöt</translation>
     </message>
     <message>
-        <location filename="../../gui/searchdialog.cpp" line="46"/>
+        <location filename="../../gui/searchdialog.cpp" line="121"/>
         <source>Companies</source>
         <translation>Yritykset</translation>
     </message>
@@ -359,7 +387,7 @@
 <context>
     <name>Settings</name>
     <message>
-        <location filename="../settings.cpp" line="168"/>
+        <location filename="../settings.cpp" line="174"/>
         <source>fi</source>
         <translation>fi</translation>
     </message>
@@ -417,28 +445,28 @@
         <translation>Yhdistä automaattisesti</translation>
     </message>
     <message>
-        <location filename="../../gui/settingsdialog.cpp" line="112"/>
+        <location filename="../../gui/settingsdialog.cpp" line="117"/>
         <source>Save</source>
         <translation>Tallenna</translation>
     </message>
     <message>
-        <location filename="../../gui/settingsdialog.cpp" line="137"/>
+        <location filename="../../gui/settingsdialog.cpp" line="142"/>
         <source>General</source>
         <translation>Yleiset</translation>
     </message>
     <message>
-        <location filename="../../gui/settingsdialog.cpp" line="138"/>
+        <location filename="../../gui/settingsdialog.cpp" line="143"/>
         <source>Daemon</source>
         <translation>Taustaprosessi</translation>
     </message>
     <message>
-        <location filename="../../gui/settingsdialog.cpp" line="139"/>
-        <location filename="../../gui/settingsdialog.cpp" line="208"/>
+        <location filename="../../gui/settingsdialog.cpp" line="144"/>
+        <location filename="../../gui/settingsdialog.cpp" line="227"/>
         <source>Phonebook settings</source>
         <translation>Puhelinluettelo</translation>
     </message>
     <message>
-        <location filename="../../gui/settingsdialog.cpp" line="170"/>
+        <location filename="../../gui/settingsdialog.cpp" line="185"/>
         <source>Restarting daemon...</source>
         <translation>Käynnistetään palvelu uudelleen...</translation>
     </message>
@@ -448,7 +476,7 @@
         <translation>Jenirok täytyy käynnistää uudelleen, jotta uudet kieliasetukset tulevat voimaan.</translation>
     </message>
     <message numerus="yes">
-        <location filename="../../gui/settingsdialog.cpp" line="188"/>
+        <location filename="../../gui/settingsdialog.cpp" line="201"/>
         <source>%n number(s) were deleted from cache</source>
         <translation>
             <numerusform>Poistettiin %n numero välimuistista</numerusform>
