@@ -54,10 +54,19 @@ private slots:
     void incomingCall(QDBusObjectPath path, QString numbe);
     void callTerminate();
     void showTimedMessage();
+    void handleAnswer();
 
 private:
     Q_DISABLE_COPY(CallListener);
 
+    struct CallDetails
+    {
+        QString number;
+        Source::Result result;
+        bool answered;
+        unsigned int time;
+    };
+
     void search(Source::SearchDetails const& details);
     void showResult(QString const& text);
     void showDelayedResult(QString const& text, int delay);
@@ -79,8 +88,8 @@ private:
     QLabel* label_;
     static QDBusConnection systemBus_;
     int retries_;
-    QString currentSearch_;
     int timer_;
+    CallDetails* currentCall_;
 };
 
 #endif // CALLLISTENER_H
