@@ -33,6 +33,7 @@ class DetailWindow : public QMainWindow
     Q_OBJECT
 
 public:
+
     DetailWindow(QWidget* parent = 0);
 
 public slots:
@@ -44,6 +45,7 @@ private slots:
     void addToContacts();
     void copyToClipboard();
     void sendSMS();
+    void openMaps();
 
 private:
     QWidget* area_;
@@ -54,6 +56,7 @@ private:
     QMaemo5ValueButton* numberButton_;
     QDialog* addDialog_;
     QLineEdit* addContactInput_;
+    QString country_;
 
 
 };
