@@ -25,6 +25,7 @@
 #include <QtGui/QLineEdit>
 #include <QMaemo5ListPickSelector>
 #include "buttonselector.h"
+#include "source.h"
 
 class SearchDialog : public QDialog
 {
@@ -36,7 +37,7 @@ public:
     {
         QString name;
         QString location;
-        int type;
+        Source::SearchType type;
     };
 
     SearchDialog(QWidget* parent = 0);
@@ -45,6 +46,9 @@ public:
 signals:
     void search(SearchDialog::SearchDetails& details);
 
+public slots:
+    void loadSearchTypes();
+
 private slots:
     void searchPressed();
 
